@@ -23,6 +23,7 @@
 
 #include "seasim/seasim.h"
 #include "searduino.h"
+#include "boards.h"
 
 const char* seasim_get_searduino_version(void)
 {
@@ -42,7 +43,7 @@ seasim_get_generic_output(uint8_t pin, uint8_t pin_type)
 }
 
 uint8_t 
-seasim_set_generic_input(uint8_t pin, uint8_t val, uint8_t pin_type)
+seasim_set_generic_input(uint8_t pin, unsigned int val, uint8_t pin_type)
 {
   return ext_set_generic_input(pin, val, pin_type);
 }
@@ -64,7 +65,7 @@ seasim_register_log_cb(log_to_sim_callback_ptr cb)
 uint8_t
 seasim_set_input(uint8_t pin, unsigned int val, uint8_t pin_type)
 {
-  return ext_set_generic_input(pin, val, pin_type);
+  return sim_set_generic_pin_val(pin, val, pin_type);
 }
 
 
@@ -74,35 +75,6 @@ seasim_get_output(uint8_t pin, uint8_t pin_type)
   return ext_get_generic_output(pin, pin_type);
 }
 
-/*
-
-unsigned int
-seasim_get_ana_output(uint8_t pin)
-{
-  return ext_get_ana_output(pin);
-}
-
-
-uint8_t
-seasim_set_ana_input(uint8_t pin, unsigned int val)
-{
-  return ext_set_ana_input(pin, val);
-}
-
-
-uint8_t 
-seasim_get_dig_output(uint8_t pin)
-{
-  return ext_get_dig_output(pin);
-}
-
-uint8_t 
-seasim_set_dig_input(uint8_t pin, uint8_t val)
-{
-  return ext_set_dig_input(pin, val);
-}
-
-*/
 
 
 uint8_t 
@@ -154,22 +126,6 @@ seasim_set_arduino_code_name(const char* libname)
   return searduino_set_arduino_code_name(libname);
 }
 
-/*
-
-uint8_t 
-seasim_register_digout_sim_cb(do_to_sim_callback_ptr cb)
-{
-  return ext_register_digout_sim_cb(cb);
-}
-
-
-uint8_t
-seasim_register_anaout_sim_cb(ao_to_sim_callback_ptr cb)
-{
-  return ext_register_anaout_sim_cb(cb);
-}
-*/
-
 uint8_t
 seasim_register_dig_mode_sim_cb(dm_to_sim_callback_ptr cb)
 {
@@ -220,3 +176,31 @@ seasim_i2c_add_device (unsigned int device_nr,
   return i2c_add_device (device_nr, 
 			 setup_fun);
 }
+
+
+
+int
+seasim_set_board_name(char *board)
+{
+  return set_board_name(board);
+}
+
+char *
+seasim_get_board_name(void)
+{
+  char *tmp;
+  tmp = get_board_name();
+  /*
+  printf ("SEASIM board: \n");
+  printf ("SEASIM board: %p\n", tmp);
+  printf ("SEASIM board: %s\n", tmp);
+  printf ("SEASIM board: \n");
+  */
+  return tmp;
+}
+
+int 
+seasim_get_generic_pin_type(uint8_t pin)
+{
+  return get_generic_pin_type(pin);
+}
